(********************************************************************
 * COPYRIGHT -- halstrup-walcher GmbH
 ********************************************************************
 * Library: h_w
 * File: h_w.fun
 * Author: herbigs
 * Created: January 21, 2016
 ********************************************************************
 * Functions and function blocks of library h_w
 ********************************************************************)

FUNCTION_BLOCK hwMC_Move (*Starts a positioning run or manual run*) (*$GROUP=User*)
	VAR_INPUT
		pDrive : UDINT;
		Release : BOOL;
		Position : DINT;
		ManualRunToLargerValues : BOOL;
		ManualRunToSmallerValues : BOOL;
	END_VAR
	VAR_OUTPUT
		Active : BOOL;
		InPosition : BOOL;
		ActualPosition : DINT;
		Error : BOOL;
		ErrorID : UINT;
	END_VAR
	VAR
		Drive : REFERENCE TO PSx_type;
		ModuleOK_Old : BOOL;
		Release_Old : BOOL;
		Position_Old : DINT;
		StartingPhase : BOOL;
		sendSDO : BOOL;
		EplSDORead_0 : EplSDORead;
		StatusWord : UINT;
	END_VAR
END_FUNCTION_BLOCK

FUNCTION_BLOCK hwMC_Error (*Reports the state of the drive*) (*$GROUP=User*)
	VAR_INPUT
		pDrive : UDINT;
		Enable : BOOL;
	END_VAR
	VAR_OUTPUT
		Error : BOOL;
		ErrorID : UINT;
		ErrorDescription : STRING[80];
	END_VAR
	VAR
		Drive : REFERENCE TO PSx_type;
	END_VAR
END_FUNCTION_BLOCK

FUNCTION_BLOCK hwMC_ReadParameter (*Reads one or more parameters from the PSx3xxPL*) (*$GROUP=Anwender*)
	VAR_INPUT
		pDrive : UDINT;
		Execute : BOOL;
		StatusWord_Enable : BOOL;
		ActualSpeed_Enable : BOOL;
		ActualPosition_Enable : BOOL;
		ActualTorque_Enable : BOOL;
		MaxTorqueLastRun_Enable : BOOL;
		U_Control_Enable : BOOL;
		U_Motor_Enable : BOOL;
		DeviceTemperature_Enable : BOOL;
		ProductionDate_Enable : BOOL;
		SerialNumber_Enable : BOOL;
		DeviceVariant_Enable : BOOL;
		SoftwareVersion_Enable : BOOL;
		ControlWord_Enable : BOOL;
		TargetPosition_Enable : BOOL;
		DirRotation_Enable : BOOL;
		PosScaleNumerator_Enable : BOOL;
		PosScaleDenominator_Enable : BOOL;
		ReferencingValue_Enable : BOOL;
		UpperMappingEnd_Enable : BOOL;
		UpperLimit_Enable : BOOL;
		LowerLimit_Enable : BOOL;
		PositionWindow_Enable : BOOL;
		LoopLength_Enable : BOOL;
		DragError_Enable : BOOL;
		Readjustment_Enable : BOOL;
		DragErrorCorrection_Enable : BOOL;
		TargetSpeed_Enable : BOOL;
		TargetSpeedManual_Enable : BOOL;
		SpeedLimitAbort_Enable : BOOL;
		Acceleration_Enable : BOOL;
		Deceleration_Enable : BOOL;
		MaxStartTorque_Enable : BOOL;
		MaxTorque_Enable : BOOL;
		MaxHoldTorqueEndRun_Enable : BOOL;
		MaxHoldTorque_Enable : BOOL;
		AbortRunTime_Enable : BOOL;
		StartTorqueTime_Enable : BOOL;
		MaxHoldTorqueEndRunTime_Enable : BOOL;
		DirectionChangeTime_Enable : BOOL;
		BreakReleaseTimeEndRun_Enable : BOOL;
		MotVoltageFilterTime_Enable : BOOL;
		GeneralPurpose_1_Enable : BOOL;
		GeneralPurpose_2_Enable : BOOL;
		GeneralPurpose_3_Enable : BOOL;
		GeneralPurpose_4_Enable : BOOL;
		GeneralPurpose_5_Enable : BOOL;
		GeneralPurpose_6_Enable : BOOL;
		GeneralPurpose_7_Enable : BOOL;
		GeneralPurpose_8_Enable : BOOL;
		GeneralPurpose_9_Enable : BOOL;
		GeneralPurpose_10_Enable : BOOL;
		MinVoltage_Enable : BOOL;
		MaxTemperature_Enable : BOOL;
		Address_Enable : BOOL;
		ConfigConnectionTimeout_Enable : BOOL;
		SafePositionConnTimeout_Enable : BOOL;
		RepetitionTimeSafePosRun_Enable : BOOL;
		DeliveryState_Enable : BOOL;
	END_VAR
	VAR_OUTPUT
		Active : BOOL;
		Done : BOOL;
		Error : BOOL;
		ErrorID : UINT;
		ErrorParameter : UINT;
		StatusWord_Value : UINT;
		ActualSpeed_Value : INT;
		ActualPosition_Value : DINT;
		ActualTorque_Value : UINT;
		MaxTorqueLastRun_Value : UINT;
		U_Control_Value : UINT;
		U_Motor_Value : UINT;
		DeviceTemperature_Value : UINT;
		ProductionDate_Value : UINT;
		SerialNumber_Value : UINT;
		DeviceVariant_Value : STRING[31];
		SoftwareVersion_Value : UINT;
		ControlWord_Value : UINT;
		TargetPosition_Value : DINT;
		DirRotation_Value : UINT;
		PosScaleNumerator_Value : UINT;
		PosScaleDenominator_Value : UINT;
		ReferencingValue_Value : DINT;
		UpperMappingEnd_Value : DINT;
		UpperLimit_Value : DINT;
		LowerLimit_Value : DINT;
		PositionWindow_Value : UINT;
		LoopLength_Value : DINT;
		DragError_Value : UINT;
		Readjustment_Value : USINT;
		DragErrorCorrection_Value : UINT;
		TargetSpeed_Value : UINT;
		TargetSpeedManual_Value : UINT;
		SpeedLimitAbort_Value : UINT;
		Acceleration_Value : UINT;
		Deceleration_Value : UINT;
		MaxStartTorque_Value : UINT;
		MaxTorque_Value : UINT;
		MaxHoldTorqueEndRun_Value : UINT;
		MaxHoldTorque_Value : UINT;
		AbortRunTime_Value : UINT;
		StartTorqueTime_Value : UINT;
		MaxHoldTorqueEndRunTime_Value : UINT;
		DirectionChangeTime_Value : UINT;
		BreakReleaseTimeEndRun_Value : UINT;
		MotVoltageFilterTime_Value : UINT;
		GeneralPurpose_1_Value : UDINT;
		GeneralPurpose_2_Value : UDINT;
		GeneralPurpose_3_Value : UDINT;
		GeneralPurpose_4_Value : UDINT;
		GeneralPurpose_5_Value : UDINT;
		GeneralPurpose_6_Value : UDINT;
		GeneralPurpose_7_Value : UDINT;
		GeneralPurpose_8_Value : UDINT;
		GeneralPurpose_9_Value : UDINT;
		GeneralPurpose_10_Value : UDINT;
		MinVoltage_Value : UINT;
		MaxTemperature_Value : UINT;
		Address_Value : UINT;
		ConfigConnectionTimeout_Value : UINT;
		SafePositionConnTimeout_Value : DINT;
		RepetitionTimeSafePosRun_Value : DINT;
		DeliveryState_Value : INT;
	END_VAR
	VAR
		Drive : REFERENCE TO PSx_type;
		EplSDORead_0 : EplSDORead;
		state : UINT;
	END_VAR
END_FUNCTION_BLOCK

FUNCTION_BLOCK hwMC_Parametrization (*Writes one or more parameters to the PSx3xxPL*) (*$GROUP=User*)
	VAR_INPUT
		pDrive : UDINT;
		Execute : BOOL;
		DeliveryState : BOOL;
		DirRotation_Enable : BOOL;
		DirRotation_Value : UINT;
		PosScaleNumerator_Enable : BOOL;
		PosScaleNumerator_Value : UINT;
		PosScaleDenominator_Enable : BOOL;
		PosScaleDenominator_Value : UINT;
		ActualPosition_Enable : BOOL;
		ActualPosition_Value : DINT;
		ReferencingValue_Enable : BOOL;
		ReferencingValue_Value : DINT;
		UpperMappingEnd_Enable : BOOL;
		UpperMappingEnd_Value : DINT;
		UpperLimit_Enable : BOOL;
		UpperLimit_Value : DINT;
		LowerLimit_Enable : BOOL;
		LowerLimit_Value : DINT;
		PositionWindow_Enable : BOOL;
		PositionWindow_Value : UINT;
		LoopLength_Enable : BOOL;
		LoopLength_Value : DINT;
		DragError_Enable : BOOL;
		DragError_Value : UINT;
		Readjustment_Enable : BOOL;
		Readjustment_Value : USINT;
		DragErrorCorrection_Enable : BOOL;
		DragErrorCorrection_Value : UINT;
		TargetSpeed_Enable : BOOL;
		TargetSpeed_Value : UINT;
		TargetSpeedManual_Enable : BOOL;
		TargetSpeedManual_Value : UINT;
		SpeedLimitAbort_Enable : BOOL;
		SpeedLimitAbort_Value : UINT;
		Acceleration_Enable : BOOL;
		Acceleration_Value : UINT;
		Deceleration_Enable : BOOL;
		Deceleration_Value : UINT;
		MaxStartTorque_Enable : BOOL;
		MaxStartTorque_Value : UINT;
		MaxTorque_Enable : BOOL;
		MaxTorque_Value : UINT;
		MaxHoldTorqueEndRun_Enable : BOOL;
		MaxHoldTorqueEndRun_Value : UINT;
		MaxHoldTorque_Enable : BOOL;
		MaxHoldTorque_Value : UINT;
		AbortRunTime_Enable : BOOL;
		AbortRunTime_Value : UINT;
		StartTorqueTime_Enable : BOOL;
		StartTorqueTime_Value : UINT;
		MaxHoldTorqueEndRunTime_Enable : BOOL;
		MaxHoldTorqueEndRunTime_Value : UINT;
		DirectionChangeTime_Enable : BOOL;
		DirectionChangeTime_Value : UINT;
		BreakReleaseTimeEndRun_Enable : BOOL;
		BreakReleaseTimeEndRun_Value : UINT;
		MotVoltageFilterTime_Enable : BOOL;
		MotVoltageFilterTime_Value : UINT;
		GeneralPurpose_1_Enable : BOOL;
		GeneralPurpose_1_Value : UDINT;
		GeneralPurpose_2_Enable : BOOL;
		GeneralPurpose_2_Value : UDINT;
		GeneralPurpose_3_Enable : BOOL;
		GeneralPurpose_3_Value : UDINT;
		GeneralPurpose_4_Enable : BOOL;
		GeneralPurpose_4_Value : UDINT;
		GeneralPurpose_5_Enable : BOOL;
		GeneralPurpose_5_Value : UDINT;
		GeneralPurpose_6_Enable : BOOL;
		GeneralPurpose_6_Value : UDINT;
		GeneralPurpose_7_Enable : BOOL;
		GeneralPurpose_7_Value : UDINT;
		GeneralPurpose_8_Enable : BOOL;
		GeneralPurpose_8_Value : UDINT;
		GeneralPurpose_9_Enable : BOOL;
		GeneralPurpose_9_Value : UDINT;
		GeneralPurpose_10_Enable : BOOL;
		GeneralPurpose_10_Value : UDINT;
		MinVoltage_Enable : BOOL;
		MinVoltage_Value : UINT;
		MaxTemperature_Enable : BOOL;
		MaxTemperature_Value : UINT;
		Address_Enable : BOOL;
		Address_Value : UINT;
		ConfigConnectionTimeout_Enable : BOOL;
		ConfigConnectionTimeout_Value : UINT;
		SafePositionConnTimeout_Enable : BOOL;
		SafePositionConnTimeout_Value : DINT;
		RepetitionTimeSafePosRun_Enable : BOOL;
		RepetitionTimeSafePosRun_Value : DINT;
		SaveSettings : BOOL;
	END_VAR
	VAR_OUTPUT
		Active : BOOL;
		Done : BOOL;
		Error : BOOL;
		ErrorID : UINT;
		ErrorParameter : UINT;
	END_VAR
	VAR
		Drive : REFERENCE TO PSx_type;
		EplSDOWrite_0 : EplSDOWrite;
		Value : DINT;
		state : UINT;
	END_VAR
END_FUNCTION_BLOCK

FUNCTION_BLOCK hwMC_PositionParametrization (*Writes parametrization of position data to the PSx3xxPL*) (*$GROUP=User*)
	VAR_INPUT
		pDrive : UDINT;
		Execute : BOOL;
		Direction : UINT;
		StepsPerTurn : UINT;
		LowerLimit : DINT;
		UpperLimit : DINT;
		SetPoint : DINT;
		SaveSettings : BOOL;
	END_VAR
	VAR_OUTPUT
		Active : BOOL;
		Done : BOOL;
		Error : BOOL;
		ErrorID : UINT;
		ErrorParameter : UINT;
	END_VAR
	VAR
		Drive : REFERENCE TO PSx_type;
		EplSDOWrite_0 : EplSDOWrite;
		Value : DINT;
		state : UINT;
	END_VAR
END_FUNCTION_BLOCK
